@@ -26,7 +26,7 @@ BEGIN {
     $EMPTY = q{};
 }
 my $SPACE = q{ };
-our $VERSION = '2.11.2';
+our $VERSION = '2.12.1';
 
 use Glib::Object::Subclass GooCanvas2::CanvasGroup::, signals => {
     'text-changed' => {
@@ -479,13 +479,20 @@ sub update_box {
         if ( $self->get('type') ne 'page' ) {
             $self->set( bbox => $selection );
             $text_w->set_simple_transform( 0, 0, 1, 0 );
-            my $bounds    = $text_w->get_bounds;
-            my $textangle = $self->get('textangle');
-            my $scale =
-              ( $textangle ? $selection->{height} : $selection->{width} ) /
-              ( $bounds->x2 - $bounds->x1 );
+            my $bounds         = $text_w->get_bounds;
+            my @transformation = @{ $self->get('transformation') };
+            my $rotation       = (@transformation) ? $transformation[0] : 0;
+            my $textangle      = $self->get('textangle');
+            my $angle          = -( $textangle + $rotation ) % $_360_DEGREES;
 
-            $self->transform_text( $scale, $textangle );
+            # don't scale & rotate if text has no width
+            if ( $bounds->x1 != $bounds->x2 ) {
+                my $scale =
+                  ( $angle ? $selection->{height} : $selection->{width} ) /
+                  ( $bounds->x2 - $bounds->x1 );
+
+                $self->transform_text( $scale, $angle );
+            }
         }
 
         my $new_conf = $self->get('confidence');
